﻿using System.Collections.ObjectModel;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace HighlightMultipleShapes.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            Map map = new Map("Map1",
                     new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                     new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));
            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
            map.MapUnit = GeographyUnit.DecimalDegree;

            WorldMapKitWmsWebOverlay worldMapKitOverlay = new WorldMapKitWmsWebOverlay("WorldMapKitOverlay");
            map.CustomOverlays.Add(worldMapKitOverlay);

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(Server.MapPath("~/App_Data/Countries02.shp"));
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.FromArgb(100, GeoColor.SimpleColors.Green));
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay staticOverlay = new LayerOverlay("WorldStaticOverlay");
            staticOverlay.IsBaseOverlay = false;
            staticOverlay.Layers.Add("WorldLayer", worldLayer);

            InMemoryFeatureLayer highlightLayer = new InMemoryFeatureLayer();
            highlightLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, 60, 180, 60), GeoColor.GeographicColors.DeepOcean);
            highlightLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay dynamicOverlay = new LayerOverlay("HightLightDynamicOverlay");
            dynamicOverlay.Layers.Add("HighLightLayer", highlightLayer);
            dynamicOverlay.IsBaseOverlay = false;

            map.CustomOverlays.Add(staticOverlay);
            map.CustomOverlays.Add(dynamicOverlay);

            return View(map);
        }

        [MapActionFilter]
        public string FindFeatureClick(Map map, GeoCollection<object> args)
        {
            PointShape position = new PointShape(double.Parse(args[0].ToString()), double.Parse(args[1].ToString()));

            LayerOverlay staticOverlay = (LayerOverlay)map.CustomOverlays["WorldStaticOverlay"];
            LayerOverlay dynamicOverlay = (LayerOverlay)map.CustomOverlays["HightLightDynamicOverlay"];

            ShapeFileFeatureLayer shapeFileLayer = (ShapeFileFeatureLayer)(staticOverlay.Layers["WorldLayer"]);
            InMemoryFeatureLayer highLightLayer = (InMemoryFeatureLayer)(dynamicOverlay.Layers["HighLightLayer"]);
            //highLightLayer.InternalFeatures.Clear();

            shapeFileLayer.Open();
            Collection<Feature> selectedFeatures = shapeFileLayer.QueryTools.GetFeaturesContaining(position, new string[] { "CNTRY_NAME", "POP_CNTRY", "COLOR_MAP" });
            shapeFileLayer.Close();

            foreach (Feature feature in selectedFeatures)
            {
                highLightLayer.InternalFeatures.Add(feature.Id, feature);
            }

            return string.Empty;
        }
    }
}